@@ -1,5 +1,5 @@
 plot.etasclass <-
-function(x,pdf=FALSE,file ="etasplot.pdf", ngrid=200,flag.3D=TRUE,flag.log=FALSE,...){
+function(x,pdf=FALSE,file ="etasplot.pdf", ngrid=201,flag.3D=TRUE,flag.log=FALSE,...){
 
 cat("Computation of the ETAS integrated intensity on a grid","\n")
 cat("for large catalogs computation can take some minutes. Please wait ...","\n")
@@ -14,10 +14,6 @@ else
 dev.new()
 }
 #####################################################
-
-
-
-
 ### computation of back intensity and triggered intensity on a given x-y grid
 ### back.grid computed with the same kernel used for back.dens on observed  points
 ## back.grid computed on km coordinates
@@ -40,14 +36,13 @@ params	=x$params
 #
 rangex		=range(xcat.km)
 rangey		=range(ycat.km)
+ranget=diff(range(x$cat$time))
+
 space.grid	=xy.grid(rangex,rangey,ngrid)
 ngridtot	=length(space.grid[,1])
-back.grid	=mu*kde2dnew.fortran(xcat.km,ycat.km,space.grid[,1],space.grid[,2],w=w,factor.xy=1,h=hdef)$z
-	
+back.grid	=ranget*mu*kde2dnew.fortran(xcat.km,ycat.km,space.grid[,1],space.grid[,2],w=w,factor.xy=1,h=hdef)$z
 	
 #### computation MUST be in km IN THIS VERSION because parameters are evaluated in km
-
-
 ris=.Fortran("etasfull8tintegrated" ,NAOK=TRUE,
 			n=as.integer(n),
 			mu=as.double(mu),k=as.double(k0),
@@ -57,8 +52,7 @@ ris=.Fortran("etasfull8tintegrated" ,NAOK=TRUE,
 			x=as.double(xcat.km),y=as.double(ycat.km), t=as.double(x$cat$time),m=as.double(x$cat$magn1),l=back.grid,
 			ngridtot=as.integer(ngridtot), xgrid=as.double(space.grid[,1]), ygrid=as.double(space.grid[,2]),tmax=as.double(max(x$cat$time)))
 			trig.grid	=ris$l
-	
-			
+				
 rangex		=range(x$cat.longlat$long)
 rangey		=range(x$cat.longlat$lat)
 space.grid	=xy.grid(rangex,rangey,ngrid)
@@ -68,9 +62,7 @@ ngridtot	=length(space.grid[,1])
 			y.grid		=seq(rangey[1],rangey[2],length=ngrid)
 ### trig.grid intensity on a x-y grid   by time integration of ETAS intensity function
 ###########################################################################################
-
 }
-
 tot.grid=back.grid+trig.grid
 if(flag.log) {
     back.grid=log(back.grid)
@@ -78,10 +70,8 @@ if(flag.log) {
      tot.grid=log( tot.grid)
 }
 
-
 ### start triggered intensity plotting
 
-
 mapxy=map("worldHires",xlim=range(x$cat.longlat$long),ylim=range(x$cat.longlat$lat),plot=FALSE)
 
 image.plot(x.grid,y.grid,(matrix(trig.grid,ngrid,ngrid))
@@ -89,8 +79,7 @@ image.plot(x.grid,y.grid,(matrix(trig.grid,ngrid,ngrid))
 ,xlab="x-longitude",ylab="y-latitude"
 ,main="Triggered Intensity"
 )
-      
-      
+
 grid(col="grey")
 
 map("worldHires",add=TRUE,xlab="x-longitude",ylab="y-latitude",
@@ -121,7 +110,6 @@ box()
 
 ### start total intensity plotting
 
-
 if(!pdf) dev.new()
 
 image.plot(x.grid,y.grid,(matrix(tot.grid,ngrid,ngrid)),
@@ -138,10 +126,10 @@ box()
 ### start total intensity plotting with observed points
 ts=(x$cat$time-min(x$cat$time))/diff(range(x$cat$time))
 
-
 if(!pdf) dev.new()
 
-image.plot(x.grid,y.grid,(matrix(tot.grid,ngrid,ngrid)),
+image.plot(x.grid,y.grid,
+(matrix(tot.grid,ngrid,ngrid)),
 col=gray.colors(128, start = 0., end = 1., gamma =2 ),
 xlab="x-longitude",ylab="y-latitude",main="Total Intensity with observed points \n Circles area proportional to magnitude; red: recent, blu:older"
 )
@@ -156,12 +144,10 @@ box()
 
 dev.off()
 
-
 etas.l=x$l
 
 if(flag.log) etas.l=log(etas.l)
 
-
 if(flag.3D){
 
 typegraph=2
@@ -172,12 +158,39 @@ plot3d(x$cat.longlat$long,x$cat.longlat$lat,etas.l,add=TRUE, type="h")
 
 }
 
+# computation of  intensities in observed points integrated with respect to time 
+#
+ngridtot	=n
+back.obs	=ranget*mu*kde2dnew.fortran(xcat.km,ycat.km,xcat.km,ycat.km,w=w,factor.xy=1,h=hdef)$z
+	
+#### computation MUST be in km IN THIS VERSION because parameters are evaluated in km
+ris=.Fortran("etasfull8tintegrated" ,NAOK=TRUE,
+			n=as.integer(n),
+			mu=as.double(mu),k=as.double(k0),
+			c=as.double(c),p=as.double(p),
+			a=as.double(a),g=as.double(gamma),
+			d=as.double(d),q=as.double(q),
+			x=as.double(xcat.km),y=as.double(ycat.km), t=as.double(x$cat$time),m=as.double(x$cat$magn1),l=back.obs,
+			ngridtot=as.integer(n), xgrid=as.double(xcat.km), ygrid=as.double(ycat.km),tmax=as.double(max(x$cat$time)))
+			trig.obs	=ris$l
+
+tot.obs=back.obs+trig.obs
+	
+rangex		=range(xcat.km)
+rangey		=range(ycat.km)
+
 #####################################################
 return(list(
 x.grid=x.grid,
 y.grid=y.grid,
 back.grid=back.grid,
 trig.grid=trig.grid,
-tot.grid=tot.grid
+tot.grid=tot.grid,
+back.obs=back.obs,
+trig.obs=trig.obs,
+tot.obs=tot.obs,
+ranget=ranget
 ))
 }
+
+
